=============================================================
 Tooz -- Distributed System Helper Library
=============================================================

The Tooz project aims at centralizing the most common distributed primitives
like group membership protocol, lock service and leader election by providing
a coordination API helping developers to build distributed applications. [#f1]_

Contents
========

.. toctree::
   :glob:

   install
   drivers
   compatibility
   tutorial/index
   developers

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. [#f1] It should be noted that even though it is designed with OpenStack
         integration in mind, and that is where most of its *current*
         integration is it aims to be generally usable and useful in any
         project.
